Module: PikoModel
- Defined in:
- lib/piko_model/version.rb,
lib/piko_model.rb,
lib/piko_model/model.rb
Overview
Copyright (C) 2016, 2017 Szymon Kopciewski
This file is part of PikoModel.
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/.
Defined Under Namespace
Constant Summary collapse
- VERSION =
"1.0.1"